@@ -1,7 +1,10 @@
 from .instances.base import Instance, InstanceProvider # type: ignore
-from .instances.memory import DataPoint, DataPointProvider, DataBucketProvider # type: ignore
-from .instances.text import TextInstance, TextBucketProvider, TextInstanceProvider # type: ignore
+from .instances.memory import DataPoint, DataPointProvider # type: ignore
+from .instances.text import TextInstance, TextInstanceProvider # type: ignore
 
 from .environment.base import AbstractEnvironment # type: ignore
 from .environment.memory import MemoryEnvironment  # type: ignore
 from .environment.text import TextEnvironment  # type: ignore
+
+from .labels import LabelProvider # type: ignore
+from .labels.memory import MemoryLabelProvider # type: ignore
\ No newline at end of file
